@@ -1,8 +1,9 @@
 """Inspired by Keras backend config API. https://tensorflow.google.com """
 
-import graphgallery
-from graphgallery.backend.modules import TensorFlowBackend, PyTorchBackend
 from tensorflow.keras import backend as K
+from typing import Union
+
+from graphgallery.backend import TensorFlowBackend, PyTorchBackend
 
 # used to store the model or weights for tf and torch
 POSTFIX  = ".h5"
@@ -16,6 +17,8 @@ _ALLOWED_NAME = set(list(_MODULE_KIND.keys()))
 _MODULE = {"T": TensorFlowBackend,
            "P": PyTorchBackend}
 
+_INT_TYPES = {'int16', 'int32', 'int64'}
+_FLOAT_TYPES = {'float16', 'float32', 'float64'}
 
 # The type of integer to use throughout a session.
 _INTX = 'int32'
@@ -26,130 +29,145 @@ epsilon = K.epsilon
 set_epsilon = K.set_epsilon
 
 
-def floatx():
+def floatx() -> str:
     """Returns the default float type, as a string.
 
     E.g. `'float16'`, `'float32'`, `'float64'`.
 
     Returns:
-      String, the current default float type.
+    --------
+    String, the current default float type.
 
     Example:
+    --------
     >>> graphgallery.floatx()
     'float32'
     """
     return _FLOATX
 
 
-def set_floatx(dtype):
+def set_floatx(dtype: str) -> str:
     """Sets the default float type.
 
     Parameters:
-      dtype: String; `'float16'`, `'float32'`, or `'float64'`.
+    --------
+    dtype: String; `'float16'`, `'float32'`, or `'float64'`.
 
     Example:
+    --------
     >>> graphgallery.floatx()
     'float32'
     >>> graphgallery.set_floatx('float64')
-    >>> graphgallery.floatx()
     'float64'
 
     Raises:
-      ValueError: In case of invalid value.
+    --------
+    ValueError: In case of invalid value.
     """
 
-    if dtype not in {'float16', 'float32', 'float64'}:
-        raise ValueError('Unknown floatx type: ' + str(dtype))
+    if dtype not in _FLOAT_TYPES:
+        raise ValueError(f"Unknown floatx type: '{str(dtype)}', expected one of {_FLOAT_TYPES}.")
     global _FLOATX
     _FLOATX = str(dtype)
     return _FLOATX
 
 
-def intx():
+def intx() -> str:
     """Returns the default integer type, as a string.
 
     E.g. `'int16'`, `'int32'`, `'int64'`.
 
     Returns:
-      String, the current default integer type.
+    --------
+    String, the current default integer type.
 
     Example:
+    --------
     >>> graphgallery.intx()
     'int32'
 
     Note:
     -------
-    The default integer type of PyTorch will set to be
-        'int64', i.e., 'Long'
+    The default integer type of PyTorch backend will set to
+        'int64', i.e., 'Long'.
     """
     return _INTX
 
 
-def set_intx(dtype):
+def set_intx(dtype: str) -> str:
     """Sets the default integer type.
 
     Parameters:
-      dtype: String; `'int16'`, `'int32'`, or `'int64'`.
+    --------
+    dtype: String; `'int16'`, `'int32'`, or `'int64'`.
 
     Example:
+    --------
     >>> graphgallery.intx()
     'int32'
     >>> graphgallery.set_intx('int64')
-    >>> graphgallery.intx()
     'int64'
 
     Raises:
-      ValueError: In case of invalid value.
+    --------
+    ValueError: In case of invalid value.
+    RuntimeError: PyTorch backend using other integer types.
     """
 
-    if dtype not in {'int16', 'int32', 'int64'}:
-        raise ValueError('Unknown floatx type: ' + str(dtype))
+    if dtype not in _INT_TYPES:
+        raise ValueError(f"Unknown floatx type: '{str(dtype)}', expected one of {_INT_TYPES}.")
     global _INTX
 
     if _BACKEND.kind == "P" and dtype != 'int64':
         raise RuntimeError(
-            f"For {_BACKEND}, tensors used as integer must be long (int64), not {dtype}.")
+            f"For {_BACKEND}, tensors used as integer must be long (int64), not '{str(dtype)}'.")
 
     _INTX = str(dtype)
     return _INTX
 
 
-def backend():
+def backend() -> Union[TensorFlowBackend, PyTorchBackend]:
     """Publicly accessible method
     for determining the current backend.
 
-    # Returns
-        String, the name of the backend GraphGallery is currently using.
+    Returns
+    --------
+    String, the backend that GraphGallery is currently using.
 
-    E.g. `'TensorFlow 2.1.0 Backend'`,
+    E.g. `'TensorFlow 2.1.2 Backend'`,
       `'PyTorch 1.6.0+cpu Backend'`.
 
     Returns:
-      String, the current default backend module.
+    --------
+    String, the current default backend module.
 
     Example:
+    --------
     >>> graphgallery.backend()
-    'TensorFlow 2.1.0 Backend'
+    'TensorFlow 2.1.2 Backend'
     """
     return _BACKEND
 
 
-def set_backend(module_name):
+def set_backend(module_name: str) -> Union[TensorFlowBackend, PyTorchBackend]:
     """Sets the default backend module.
 
     Parameters:
-      module_name: String; `'tf'`, `'tensorflow'`,
+    --------
+    module_name: String; `'tf'`, `'tensorflow'`,
              `'th'`, `'torch'`, 'pytorch'`.
 
     Example:
+    --------
     >>> graphgallery.backend()
-    'TensorFlow 2.1.0 Backend'
+    'TensorFlow 2.1.2 Backend'
+    
     >>> graphgallery.set_backend('torch')
-    >>> graphgallery.backend()
     'PyTorch 1.6.0+cpu Backend'
 
     Raises:
-      ValueError: In case of invalid value.
+    --------
+    ValueError: In case of invalid value.
     """
     if module_name not in _ALLOWED_NAME:
         raise ValueError(
@@ -161,7 +179,7 @@ def set_backend(module_name):
         _BACKEND = _MODULE.get(kind)()
 
         if kind == "P":
-            # PyTorch uses Long integer as default.
+            # PyTorch backend uses Long integer as default.
             set_intx('int64')
         else:
             # Using int32 is more efficient
