@@ -7,10 +7,9 @@ import scipy.sparse as sp
 from functools import lru_cache
 from copy import copy as copy_fn
 
-from graphgallery.data.base_graph import Basegraph
+from graphgallery.data.base_graph import BaseGraph
 
 
-
-class MuitiGraph(Basegraph):
+class MultiGraph(BaseGraph):
     """Attributed labeled multigraph stored in a list of sparse matrix form."""
     ...
