@@ -13,7 +13,7 @@ from sklearn.linear_model import LogisticRegression
 from sklearn.metrics import accuracy_score
 
 from graphgallery.nn.models import BaseModel
-from graphgallery.transformers import asintarr
+from graphgallery.transforms import asintarr
 
 
 class UnsupervisedModel(BaseModel):
@@ -22,7 +22,7 @@ class UnsupervisedModel(BaseModel):
     """
 
     def __init__(self, *graph, device='cpu:0', seed=None, name=None, **kwargs):
-        """Creat an unsupervised model.
+        """Create an unsupervised model.
 
         Parameters:
         ----------
